<?php
/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Malin Lorch <mlorch@liquidweb.com>
 * @date    Dec 01, 2020
 */

/**
 * Test Suite for Upgrade_Prep_IsOptedIn
 *
 * @package    InterWorx
 * @subpackage Tests
 */
class Upgrade_Prep_IsOptedInTest extends IWorx_Framework_TestCase
{
    /**
     * expects isOptedIn to return true when env flag exists.
     */
    public function testIsOptedInShouldReturnTrue()
    {
        IW::Env()->setEnvFlag('upgrade-prep-7-is-opted-in-opt-in');

        $SUT = new Upgrade_Prep_IsOptedIn();
        $this->assertTrue($SUT->isOptedIn());
    }

    /**
     * Expects isOptedIn to be false if no flag.
     */
    public function testIsOptedInShouldReturnFalse()
    {
        IW::Env()->clearEnvFlag('upgrade-prep-7-is-opted-in-opt-in');

        $SUT = new Upgrade_Prep_IsOptedIn();
        $this->assertFalse($SUT->isOptedIn());
    }

    /**
     * Expect optOut to clear env flag.
     */
    public function testOptOutShouldClearEnvFlag()
    {
        IW::Env()->setEnvFlag('upgrade-prep-7-is-opted-in-opt-in');

        $SUT = new Upgrade_Prep_IsOptedIn();
        $SUT->optOut();

        $actual = IW::Env()->getEnvFlag('upgrade-prep-7-is-opted-in-opt-in');
        $this->assertFalse($actual);
    }

    /**
     * Expect optIn to set env flag.
     */
    public function testOptInShouldSetEnvFlag()
    {
        IW::Env()->clearEnvFlag('upgrade-prep-7-is-opted-in-opt-in');

        $SUT = new Upgrade_Prep_IsOptedIn();
        $SUT->optIn();

        $actual = IW::Env()->getEnvFlag('upgrade-prep-7-is-opted-in-opt-in');
        $this->assertTrue($actual);
    }

    /**
     * Expects label for fail action is 'Opt In'
     */
    public function testGetLabelFailAction()
    {
        $SUT = new Upgrade_Prep_IsOptedIn();
        $actual = $SUT->getLabelFailAction();
        $expected = 'Opt In';
        $this->assertSame($expected, $actual);
    }

    /**
     * Expects label for pass action is 'Opt Out'
     */
    public function testGetLabelPassAction()
    {
        $SUT = new Upgrade_Prep_IsOptedIn();
        $actual = $SUT->getLabelPassAction();
        $expected = 'Opt Out';
        $this->assertSame($expected, $actual);
    }

    /**
     * Expects not ignorable.
     */
    public function testIsIgnorable()
    {
        $SUT = new Upgrade_Prep_IsOptedIn();
        $isIgnorable = $SUT->isIgnorable();
        $this->assertFalse($isIgnorable);
    }
}
